# PositionedObjectProperties

Properties of a PositionedObject.

**Type:** object

## Properties

- **positioning** ([PositionedObjectPositioning](positionedobjectpositioning.md)): The positioning of this positioned object relative to the newline of the Paragraph that references this positioned object.
- **embeddedObject** ([EmbeddedObject](embeddedobject.md)): The embedded object of this positioned object.
